@@ -26,24 +26,22 @@
 #include <QVBoxLayout>
 #include <QtGui/QKeyEvent>
 #include <qtestkeyboard.h>
-
+#include <QMenu>
+#include <QAction>
+#include <QMenuBar>
 // System
 #include <termios.h>
 #include <sys/types.h>
 
 // KDE
-#include <KMenu>
-#include <KMenuBar>
 #include <KPluginLoader>
 #include <KPluginFactory>
 #include <KService>
 #include <KParts/Part>
 #include <KPtyProcess>
 #include <KPtyDevice>
-#include <KDialog>
-#include <KDebug>
 #include <KMainWindow>
-#include <qtest_kde.h>
+#include <qtest.h>
 
 // Konsole
 #include "../Pty.h"
@@ -69,7 +67,7 @@ void PartManualTest::testShortcutOverride()
     QMenu* fileMenu = mainWindow->menuBar()->addMenu("File");
     QAction* testAction = fileMenu->addAction("Test");
     testAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_S));
-    connect(testAction, SIGNAL(triggered()), this, SLOT(shortcutTriggered()));
+    connect(testAction, &QAction::triggered, this, &Konsole::PartManualTest::shortcutTriggered);
 
     // Create terminal part and embed in into the main window
     KParts::Part* terminalPart = createPart();
@@ -137,7 +135,5 @@ KParts::Part* PartManualTest::createPart()
     return terminalPart;
 }
 
-QTEST_KDEMAIN(PartManualTest , GUI)
-
-#include "PartManualTest.moc"
+QTEST_MAIN(PartManualTest)
 
